get_interactivity

Function get_interactivity 

pub fn get_interactivity(
    child: impl IntoUiNode,
    state: impl IntoVar<Interactivity>,
) -> UiNode
P Get the widget interactivity value.

This property is used only for probing the state. You can set the state using the enabled and interactive properties.