on_blocked

Function on_blocked 

pub fn on_blocked(child: impl IntoUiNode, handler: Handler<()>) -> UiNode
Widget interactions now blocked.

Note that blocked widgets may still be visually enabled, see Interactivity for more details.

See on_blocked_changed for a more general event.

Route

This event property uses a direct route, that is, it cannot be intercepted in parent widgets.