pub fn on_disabled(child: impl IntoUiNode, handler: Handler<()>) -> UiNodeExpand description
Widget normal interactions now disabled.
Note that this event tracks the actual enabled status of the widget, not the visually enabled status,
see Interactivity for more details.
See on_enabled_changed for a more general event.
Route
This event property uses a direct route, that is, it cannot be intercepted in parent widgets.