on_vis_enabled_changed

Function on_vis_enabled_changed 

pub fn on_vis_enabled_changed(
    child: impl IntoUiNode,
    handler: Handler<bool>,
) -> UiNode
Widget changed to enabled or disabled visuals.

Note that this event tracks the visual enabled status of the widget, not the actual status, the widget may still be blocked, see Interactivity for more details.

See on_interactivity_changed for a more general interactivity event.

Route

This event property uses a direct route, that is, it cannot be intercepted in parent widgets.