EventNodeBuilder

Struct EventNodeBuilder 

pub struct EventNodeBuilder<A: EventArgs, F, M> { /* private fields */ }
Helper for declaring event properties.

Implementations

Source

impl<A: EventArgs> EventNodeBuilder<A, (), ()>

pub fn new(event: Event<A>) -> EventNodeBuilder<A, (), ()>

Node that calls the handler for all args that target the widget and has not stopped propagation.

Source

impl<A: EventArgs, M> EventNodeBuilder<A, (), M>

pub fn filter<FB, F>(self, filter_builder: FB) -> EventNodeBuilder<A, FB, M>
where FB: FnMut() -> F + Send + 'static, F: Fn(&A) -> bool + Send + Sync + 'static,

Filter event.

The filter_builder is called on init and on event, it must produce another closure, the filter predicate. The filter_builder runs in the widget context, the filter predicate does not always.

In the event hook the filter predicate runs in the app context, it is called if the args target the widget, the predicate must use any captured contextual info to filter the args, this is an optimization, it can save a visit to the widget node.

If the event is received the second filter predicate is called again to confirm the event. The second instance is called if propagation was not stopped, if it returns true the handler closure is called.

Note that events that represent an interaction with the widget are send for both ENABLED and DISABLED targets, event properties should probably distinguish if they fire on normal interactions vs on disabled interactions.

Source

impl<A: EventArgs, F> EventNodeBuilder<A, F, ()>

pub fn map_args<M, MA>(self, map_args: M) -> EventNodeBuilder<A, F, M>
where M: FnMut(&A) -> MA + Send + 'static, MA: Clone + 'static,

Convert args.

The map_args closure is called in context, just before the handler is called.

Source

impl<A, F, FB, MA, M> EventNodeBuilder<A, FB, M>
where A: EventArgs, F: Fn(&A) -> bool + Send + Sync + 'static, FB: FnMut() -> F + Send + 'static, MA: Clone + 'static, M: FnMut(&A) -> MA + Send + 'static,

Build with filter and args mapping.

pub fn build<const PRE: bool>( self, child: impl IntoUiNode, handler: Handler<MA>, ) -> UiNode

Build node.

If PRE is true the handler is called before the children, preview route.

Source

impl<A, F, FB> EventNodeBuilder<A, FB, ()>
where A: EventArgs, F: Fn(&A) -> bool + Send + Sync + 'static, FB: FnMut() -> F + Send + 'static,

Build with filter and without args mapping.

pub fn build<const PRE: bool>( self, child: impl IntoUiNode, handler: Handler<A>, ) -> UiNode

Build node.

If PRE is true the handler is called before the children, preview route.

Source

impl<A> EventNodeBuilder<A, (), ()>
where A: EventArgs,

Build without filter and without args mapping.

pub fn build<const PRE: bool>( self, child: impl IntoUiNode, handler: Handler<A>, ) -> UiNode

Build node.

If PRE is true the handler is called before the children, preview route.

Source

impl<A, MA, M> EventNodeBuilder<A, (), M>
where A: EventArgs, MA: Clone + 'static, M: FnMut(&A) -> MA + Send + 'static,

Build with no filter and args mapping.

pub fn build<const PRE: bool>( self, child: impl IntoUiNode, handler: Handler<MA>, ) -> UiNode

Build node.

If PRE is true the handler is called before the children, preview route.