pub fn on_vis_disabled(child: impl IntoUiNode, handler: Handler<()>) -> UiNodeExpand description
Widget now looks disabled.
Note that this event tracks the visual enabled status of the widget, not the actual status, the widget may
still be blocked, see Interactivity for more details.
See on_vis_enabled_changed for a more general event.
Route
This event property uses a direct route, that is, it cannot be intercepted in parent widgets.