pub fn on_visible(child: impl IntoUiNode, handler: Handler<()>) -> UiNodeExpand description
P Widget visibility changed to visible.
See on_visibility_changed for a more general visibility event.
Note that widgets are visible by default, so this will not notify on init.
Route
This event property uses a direct route, that is, it cannot be intercepted in parent widgets.