pub struct EventNodeBuilder<A: EventArgs, F, M> { /* private fields */ }Expand description
Helper for declaring event properties.
Implementations
Sourceimpl<A: EventArgs, M> EventNodeBuilder<A, (), M>
impl<A: EventArgs, M> EventNodeBuilder<A, (), M>
Sourcepub fn filter<FB, F>(self, filter_builder: FB) -> EventNodeBuilder<A, FB, M>
pub fn filter<FB, F>(self, filter_builder: FB) -> EventNodeBuilder<A, FB, M>
Filter event.
The filter_builder is called on init and on event, it must produce another closure, the filter predicate. The filter_builder
runs in the widget context, the filter predicate does not always.
In the event hook the filter predicate runs in the app context, it is called if the args target the widget, the predicate must use any captured contextual info to filter the args, this is an optimization, it can save a visit to the widget node.
If the event is received the second filter predicate is called again to confirm the event.
The second instance is called if propagation was not stopped, if it returns true the handler closure is called.
Note that events that represent an interaction with the widget are send for both ENABLED and DISABLED targets,
event properties should probably distinguish if they fire on normal interactions vs on disabled interactions.
Sourceimpl<A: EventArgs, F> EventNodeBuilder<A, F, ()>
impl<A: EventArgs, F> EventNodeBuilder<A, F, ()>
Sourceimpl<A, F, FB, MA, M> EventNodeBuilder<A, FB, M>
Build with filter and args mapping.
impl<A, F, FB, MA, M> EventNodeBuilder<A, FB, M>
Build with filter and args mapping.
Sourceimpl<A, F, FB> EventNodeBuilder<A, FB, ()>
Build with filter and without args mapping.
impl<A, F, FB> EventNodeBuilder<A, FB, ()>
Build with filter and without args mapping.
Sourceimpl<A> EventNodeBuilder<A, (), ()>where
A: EventArgs,
Build without filter and without args mapping.
impl<A> EventNodeBuilder<A, (), ()>where
A: EventArgs,
Build without filter and without args mapping.
Sourceimpl<A, MA, M> EventNodeBuilder<A, (), M>
Build with no filter and args mapping.
impl<A, MA, M> EventNodeBuilder<A, (), M>
Build with no filter and args mapping.